SystemObservationClock class final

Uses the system clock and returns UTC timestamps.

Implemented types

Constructors

SystemObservationClock()
Creates a system-backed observation clock.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
now() DateTime
Returns the current timestamp.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited